summary refs log tree commit diff
path: root/src/libsyntax/ext
diff options
context:
space:
mode:
authorHuon Wilson <dbau.pp+github@gmail.com>2015-01-08 23:36:24 +1100
committerNiko Matsakis <niko@alum.mit.edu>2015-01-08 11:02:24 -0500
commitdc1ba08d1603aeedf37a4a7182e990207891379d (patch)
tree12a12f39fb85a4e2d8aeacbd810f83a04864eea9 /src/libsyntax/ext
parent441044f071181b52144bad15a50bf91dc06771a5 (diff)
downloadrust-dc1ba08d1603aeedf37a4a7182e990207891379d.tar.gz
rust-dc1ba08d1603aeedf37a4a7182e990207891379d.zip
Test fixes.
Diffstat (limited to 'src/libsyntax/ext')
-rw-r--r--src/libsyntax/ext/deriving/rand.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/libsyntax/ext/deriving/rand.rs b/src/libsyntax/ext/deriving/rand.rs
index 5517019f804..1359cada673 100644
--- a/src/libsyntax/ext/deriving/rand.rs
+++ b/src/libsyntax/ext/deriving/rand.rs
@@ -98,13 +98,13 @@ fn rand_substructure(cx: &mut ExtCtxt, trait_span: Span, substr: &Substructure)
                                        rand_name,
                                        vec!(rng.clone()));
 
-            // need to specify the uint-ness of the random number
-            let uint_ty = cx.ty_ident(trait_span, cx.ident_of("uint"));
+            // need to specify the usize-ness of the random number
+            let usize_ty = cx.ty_ident(trait_span, cx.ident_of("usize"));
             let value_ident = cx.ident_of("__value");
             let let_statement = cx.stmt_let_typed(trait_span,
                                                   false,
                                                   value_ident,
-                                                  uint_ty,
+                                                  usize_ty,
                                                   rv_call);
 
             // rand() % variants.len()